summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
Diffstat (limited to 'tools')
-rwxr-xr-xtools/codestats.sh10
-rwxr-xr-xtools/pyboard.py2
2 files changed, 6 insertions, 6 deletions
diff --git a/tools/pyboard.py b/tools/pyboard.py
index 16ee41f70..bb5642bd7 100755
--- a/tools/pyboard.py
+++ b/tools/pyboard.py
@@ -191,7 +191,7 @@ class ProcessToSerial:
class ProcessPtyToTerminal:
- """Execute a process which creates a PTY and prints slave PTY as
+ """Execute a process which creates a PTY and prints secondary PTY as
first line of its output, and emulate serial connection using
this PTY."""
diff --git a/tools/codestats.sh b/tools/codestats.sh
index d33db973b..5f7625c45 100755
--- a/tools/codestats.sh
+++ b/tools/codestats.sh
@@ -90,9 +90,9 @@ else
last_rev="v1.0"
fi
-# get a list of hashes between last revision (exclusive) and master
-hashes=$(git log --format=format:"%H" --reverse ${last_rev}..master)
-#hashes=$(git log --format=format:"%H" --reverse ${last_rev}..master | $AWK '{if (NR % 10 == 0) print $0}') # do every 10th one
+# get a list of hashes between last revision (exclusive) and main
+hashes=$(git log --format=format:"%H" --reverse ${last_rev}..main)
+#hashes=$(git log --format=format:"%H" --reverse ${last_rev}..main | $AWK '{if (NR % 10 == 0) print $0}') # do every 10th one
for hash in $hashes; do
@@ -182,6 +182,6 @@ EOF
done
-# checkout master and cleanup
-git checkout master
+# checkout main and cleanup
+git checkout main
$RM $pystoneavg